@@ -11,8 +11,6 @@
 
 #include <qqmlregistration.h>
 
-#include <QMimeData>
-
 namespace Milou
 {
 class ResultsModel : public KRunner::ResultsModel
@@ -34,12 +32,6 @@ public:
         KRunner::ResultsModel::setFavoriteIds(m_configFavoriteIds);
     }
 
-    // Workaround for https://bugs.kde.org/show_bug.cgi?id=511228
-    Q_INVOKABLE QMimeData *getMimeData(const QModelIndex &idx) const
-    {
-        return KRunner::ResultsModel::getMimeData(idx);
-    }
-
 private:
     KConfigWatcher::Ptr m_configWatcher;
     QStringList m_configFavoriteIds;
